InPlace.BitSet
(inplace v0.6.5)
BitSet is close in functionality to MapSet with integer values a s members. The main difference is that BitSet has lower and upper bounds for set values that have to be defined at the time of creation (see new/2).
Summary
Functions
Find next position for {block_idx, block_offset}
Functions
Find next position for {block_idx, block_offset}