InPlace.ExactCover (inplace v0.4.4)

Implementation of Algorithm DLX (Exact cover via dancing links). Based on https://arxiv.org/pdf/cs/0011047 by Donald Knuth.

Note: there is a never version of this algorithm (The Art of Computer Programming, vol. 4B, by Donald Knuth). It differs mostly by using more advanced internal state structure.

Summary

Functions

cover(column_pointer, state)

first_item(state)

increase_option_count(state, item_option_pointer)

init(options)

min_options_item(state)

num_solutions(state)

random_item(state)

solve(options, solver_opts \\ [])

uncover(column_pointer, state)

update_option_count(state, item_header_pointer, update_fun)