InPlace.BitSet
(inplace v0.7.1)
BitSet is close in functionality to MapSet with integer values as members. The main difference is that BitSet has lower and upper bounds for set values that have to be defined at the time of creation (see new/2).