InPlace.Examples.Sudoku
(inplace v0.7.1)
Sudoku puzzle. The instance of puzzle is a string of DxD length , where D is a dimension of Sudoku puzzle (would be 9 by default). The values 1 to 9 represent pre-filled cells (clues, givens etc...); any other values represent hidden cells.
Summary
Functions
solution is a list of integers
representing the 'flattened' solved puzzle
solution is a "cover" (list of indices into options
built off the Sudoku instance).
Note: the options only represent "hidden" cells.
Solver
Functions
solution is a list of integers
representing the 'flattened' solved puzzle
solution is a "cover" (list of indices into options
built off the Sudoku instance).
Note: the options only represent "hidden" cells.
Solver